@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2013, Stefan Schwarzer <sschwarzer@sschwarzer.net>
+# Copyright (C) 2006-2018, Stefan Schwarzer <sschwarzer@sschwarzer.net>
 # and ftputil contributors (see `doc/contributors.txt`)
 # See the file LICENSE for licensing terms.
 
@@ -6,18 +6,17 @@
 Provide version information about ftputil and the runtime environment.
 """
 
-from __future__ import unicode_literals
-
 import sys
 
 
 # ftputil version number; substituted by `make patch`
-__version__ = "3.2"
+__version__ = "4.0.0"
 
 _ftputil_version = __version__
 _python_version = sys.version.split()[0]
 _python_platform = sys.platform
 
 
-version_info = "ftputil {0}, Python {1} ({2})".format(
-                 _ftputil_version, _python_version, _python_platform)
+version_info = "ftputil {}, Python {} ({})".format(
+    _ftputil_version, _python_version, _python_platform
+)
