@@ -1,15 +1,11 @@
-# Copyright (C) 2007-2013, Stefan Schwarzer <sschwarzer@sschwarzer.net>
+# Copyright (C) 2007-2018, Stefan Schwarzer <sschwarzer@sschwarzer.net>
 # and ftputil contributors (see `doc/contributors.txt`)
 # See the file LICENSE for licensing terms.
 
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 import io
 import ntpath
 import os
 import shutil
-import unittest
 
 import ftputil
 import ftputil.sync
@@ -19,9 +15,8 @@ import ftputil.sync
 TEST_ROOT = os.getcwd()
 
 
-class TestLocalToLocal(unittest.TestCase):
-
-    def setUp(self):
+class TestLocalToLocal:
+    def setup_method(self, method):
         if not os.path.exists("test_empty"):
             os.mkdir("test_empty")
         if os.path.exists("test_target"):
@@ -47,8 +42,8 @@ class TestLocalToLocal(unittest.TestCase):
 
 # Helper classes for `TestUploadFromWindows`
 
-class LocalWindowsHost(ftputil.sync.LocalHost):
 
+class LocalWindowsHost(ftputil.sync.LocalHost):
     def __init__(self):
         self.path = ntpath
         self.sep = "\\"
@@ -71,38 +66,32 @@ class LocalWindowsHost(ftputil.sync.LocalHost):
         where <root> is the string passed in as `root`.
         """
         join = ntpath.join
-        return [(root,
-                 [join(root, "dir1")],
-                 []),
-                (join(root, "dir1"),
-                 ["dir11"],
-                 ["file1", "file2"])
-                ]
+        return [
+            (root, [join(root, "dir1")], []),
+            (join(root, "dir1"), ["dir11"], ["file1", "file2"]),
+        ]
 
 
-class DummyFTPSession(object):
-
+class DummyFTPSession:
     def pwd(self):
         return "/"
 
 
-class DummyFTPPath(object):
-
+class DummyFTPPath:
     def abspath(self, path):
         # Don't care here if the path is absolute or not.
         return path
 
     def isdir(self, path):
-        return ("dir" in path)
+        return "dir" in path
 
     def isfile(self, path):
-        return ("file" in path)
+        return "file" in path
 
 
 class ArgumentCheckingFTPHost(ftputil.FTPHost):
-
     def __init__(self, *args, **kwargs):
-        super(ArgumentCheckingFTPHost, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.path = DummyFTPPath()
 
     def _make_session(self, *args, **kwargs):
@@ -116,17 +105,12 @@ class ArgumentCheckingFTPHost(ftputil.FTPHost):
         return io.StringIO("")
 
 
-class TestUploadFromWindows(unittest.TestCase):
-
+class TestUploadFromWindows:
     def test_no_mixed_separators(self):
         source = LocalWindowsHost()
         target = ArgumentCheckingFTPHost()
         local_root = ntpath.join("some", "directory")
         syncer = ftputil.sync.Syncer(source, target)
-        # If the following call raises any `AssertionError`s, the
-        # `unittest` framework will catch them and show them.
+        # If the following call raises any `AssertionError`s, the test
+        # framework will catch them and show them.
         syncer.sync(local_root, "not_used_by_ArgumentCheckingFTPHost")
-
-
-if __name__ == "__main__":
-    unittest.main()
